package com.objis.demospringmvc.test;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import junit.framework.TestCase;

import org.springframework.mock.web.MockHttpServletRequest;
import org.springframework.mock.web.MockHttpServletResponse;
import org.springframework.web.servlet.ModelAndView;

import com.objis.springmvcdemo.controleur.HomePageController;
import com.objis.springmvcdemo.domaine.Employe;
import com.objis.springmvcdemo.service.IEmployeManager;

// Easymock Action 1 : import static des mthodes d'easyMock (Ex : createMock)
import static org.easymock.EasyMock.*;

public class HomePageControllerTest extends TestCase {

	private HomePageController controller;
	private IEmployeManager mock;
	
	@SuppressWarnings("unchecked")
	public void testControlleurSimple(){
		
		// Objets factices pour simuler qu'on est dans serveur j2ee
		MockHttpServletRequest request = new MockHttpServletRequest();
		MockHttpServletResponse response = new MockHttpServletResponse();
		
		request.setMethod("POST");
		request.setRequestURI("http://localhost:8080/demospringmvc/home.htm");
		//request.addParameter("cle", "valeur");
		
			try {
				ModelAndView modelAndView =	controller.handleRequestInternal(request, response);
				assertNotNull("ModelAndView ne devrait pas tre null", modelAndView);
				assertEquals("Le nom de la vue devrait tre 'home'", "home", modelAndView.getViewName());
				Map model = modelAndView.getModel();
				assertTrue("Le modle devrait avoir la cl 'employes'",	model.containsKey("employes"));
				List listEmployes = (List) model.get("employes");
				assertNotNull("le Model 'listEmployes' ne devrait pas tre null", listEmployes);
				assertEquals("Le Model 'listEmployes' devrait contenir 2 lments",2, listEmployes.size());
				
			} catch (Exception e) {
				// TODO: handle exception
				e.printStackTrace();
			}

	}
	
	@Override
	protected void setUp() throws Exception {

		// Instancier controlleur  tester
		controller = new HomePageController();
		
		// Easymock Action 2 (suite  import statique) : cration d'un objet factice
		mock = createMock(IEmployeManager.class);
		
		// prparer rsultat attendu
		List<Employe> listeAttendueEmployes = new ArrayList<Employe>();
		Employe employe1 = new Employe(1,"douglas","objis","Douglas","MBIANDOU","douglas.mbiandou@objis.com","manager");
		Employe employe2 = new Employe(1,"aa","cc","dd","ee","aa.mbiandou@objis.com","manager");
		listeAttendueEmployes.add(employe1);
		listeAttendueEmployes.add(employe2);
		
		// Easymock Action 3 : faire travailler l'object factice - Lui prciser rsultat  renvoyer
		expect(mock.getAllEmployes()).andReturn(listeAttendueEmployes);
		
		// Easymock Action 4 : rejouer
		replay(mock);
		
		// Injection du manager factice
		controller.setEmployeManager(mock);
	}

	@Override
	protected void tearDown() throws Exception {
		// TODO Auto-generated method stub
		super.tearDown();
	}

}
